Welcome to pytrip98's documentation!
====================================

Contents:

.. toctree::
   :maxdepth: 2

   readme
   technical
   contributing
   authors

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

